IMaster class abstract

Constructors

IMaster()

Properties

by String
getter/setter pair
createdAt int
getter/setter pair
deleted int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isActive bool
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverAt int
getter/setter pair
updatedAt int
getter/setter pair
uuid String
getter/setter pair

Methods

created({int? at}) → void
fromMap(Map<String, dynamic> map) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCreated() → void
onFromMap(Map<String, dynamic> map) → void
From Map
onToJson() Map<String, dynamic>
To Json
onToMap() Map<String, dynamic>
To Map
onUpdated() → void
toJson() Map<String, dynamic>
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override
updated({int? at}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited