JDB class

Properties

database Future<Database>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

by String
getter/setter pair
instance JDB
final
path String
getter/setter pair

Static Methods

initialize({required String name, required Future<void> onCreateTables(Database db)}) Future<bool>