JColors class
Constructors
- JColors()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- colorAccount → Color
-
final
- colorCardBackground → Color
-
final
- screenBackground → Color
-
final
- sizeIconButton → double
-
final
- styleButton → TextStyle
-
final
- styleEntry → TextStyle
-
final
- styleEntryAmount → TextStyle
-
final
- styleEntryHint → TextStyle
-
final
- styleEntryLabel → TextStyle
-
final
- styleLabelCard → TextStyle
-
final
- styleNameCard → TextStyle
-
final
Constants
- blue → const Color
- colorEntryBackground → const Color
- colorEntryStroke → const Color
- colorEntryStrokeFocused → const Color
- colorLabel → const Color
- green → const Color
- jBlue1 → const Color
- jBlue2 → const Color
- jBlue3 → const Color
- jBlue4 → const Color
- jBlue5 → const Color
- jRed → const Color
- lucky → const Color
- red → const Color
- yellow → const Color