TMaster<T extends IMaster> class abstract

Constructors

TMaster()

Properties

columns String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table String
no setter

Methods

add(T item) Future<int>
Add Or Edit
addRange(List<T> items) Future<void>
Add Range
clear() Future<void>
Clear
createTable() String
fromMap(Map<String, dynamic> map) → T
Concrete subclasses must provide a factory to create T from a map.
getAll({String? orderBy}) Future<List<T>>
Get All
getByUuid(String uuid) Future<T?>
Get By Uuid
lastServerAt() Future<int>
Last Server At
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

by → const String
createdAt → const String
deleted → const String
isActive → const String
name → const String
serverAt → const String
updatedAt → const String
uuid → const String