JMessage class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
alert({required BuildContext context, required String content, int counter = 10, String title = 'تنبيه', String description = '', String confirmText = 'نعم', String cancelText = 'لا', Color colorConfirm = JColors.green, Color colorCancel = JColors.red, required Future<void> onConfirm()})
→ Future<void>
-
Show Alert Dialog
-
error(String message)
→ void
-
Show Error Toast
-
info(String message)
→ void
-
Show Info Toast
-
loading(BuildContext context, Future<void> task())
→ Future<void>
-
Show Loading Dialog while performing a task
-
success(String message)
→ void
-
Show Success Toast